<?php

/**
 * Register all actions and filters for the plugin
 *
 * @link       https://www.insightengine.online/
 * @since      1.0.0
 *
 * @package    Aielatex
 * @subpackage Aielatex/includes
 */

/**
 * Register all actions and filters for the plugin.
 *
 * Maintain a list of all hooks that are registered throughout
 * the plugin, and register them with the WordPress API. Call the
 * run function to execute the list of actions and filters.
 *
 * @package    Aielatex
 * @subpackage Aielatex/includes
 * @author     Kevin K. @ Insight Engine <kevinkno@gmail.com>
 */
class Aielatex_Loader {

	/**
	 * The array of actions registered with WordPress.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      array    $actions    The actions registered with WordPress to fire when the plugin loads.
	 */
	protected $actions;

	/**
	 * The array of filters registered with WordPress.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      array    $filters    The filters registered with WordPress to fire when the plugin loads.
	 */
	protected $filters;

	/**
	 * Initialize the collections used to maintain the actions and filters.
	 *
	 * @since    1.0.0
	 */
	public function __construct() {

		$this->actions = array();
		$this->filters = array();

	}

	/**
	 * Add a new action to the collection to be registered with WordPress.
	 *
	 * @since    1.0.0
	 * @param    string               $hook             The name of the WordPress action that is being registered.
	 * @param    object               $component        A reference to the instance of the object on which the action is defined.
	 * @param    string               $callback         The name of the function definition on the $component.
	 * @param    int                  $priority         Optional. The priority at which the function should be fired. Default is 10.
	 * @param    int                  $accepted_args    Optional. The number of arguments that should be passed to the $callback. Default is 1.
	 */
	public function add_action( $hook, $component, $callback, $priority = 10, $accepted_args = 1 ) {
		$this->actions = $this->add( $this->actions, $hook, $component, $callback, $priority, $accepted_args );
	}

	/**
	 * Add a new filter to the collection to be registered with WordPress.
	 *
	 * @since    1.0.0
	 * @param    string               $hook             The name of the WordPress filter that is being registered.
	 * @param    object               $component        A reference to the instance of the object on which the filter is defined.
	 * @param    string               $callback         The name of the function definition on the $component.
	 * @param    int                  $priority         Optional. The priority at which the function should be fired. Default is 10.
	 * @param    int                  $accepted_args    Optional. The number of arguments that should be passed to the $callback. Default is 1
	 */
	public function add_filter( $hook, $component, $callback, $priority = 10, $accepted_args = 1 ) {
		$this->filters = $this->add( $this->filters, $hook, $component, $callback, $priority, $accepted_args );
	}

	/**
	 * A utility function that is used to register the actions and hooks into a single
	 * collection.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @param    array                $hooks            The collection of hooks that is being registered (that is, actions or filters).
	 * @param    string               $hook             The name of the WordPress filter that is being registered.
	 * @param    object               $component        A reference to the instance of the object on which the filter is defined.
	 * @param    string               $callback         The name of the function definition on the $component.
	 * @param    int                  $priority         The priority at which the function should be fired.
	 * @param    int                  $accepted_args    The number of arguments that should be passed to the $callback.
	 * @return   array                                  The collection of actions and filters registered with WordPress.
	 */
	private function add( $hooks, $hook, $component, $callback, $priority, $accepted_args ) {

		$hooks[] = array(
			'hook'          => $hook,
			'component'     => $component,
			'callback'      => $callback,
			'priority'      => $priority,
			'accepted_args' => $accepted_args
		);

		return $hooks;

	}

	/**
	 * Register the filters and actions with WordPress.
	 *
	 * @since    1.0.0
	 */
	public function run() {

		foreach ( $this->filters as $hook ) {
			add_filter( $hook['hook'], array( $hook['component'], $hook['callback'] ), $hook['priority'], $hook['accepted_args'] );
		}

		foreach ( $this->actions as $hook ) {
			add_action( $hook['hook'], array( $hook['component'], $hook['callback'] ), $hook['priority'], $hook['accepted_args'] );
		}

	}

}

add_filter( 'mwai_stream_push', function ( $data ) {
	$postData = file_get_contents('php://input');
	$decodedData = json_decode($postData, true);
	$botId = isset($decodedData['botId']) ? $decodedData['botId'] : null;
	$customId = isset($decodedData['customId']) ? $decodedData['customId'] : null;
	$id = $customId ?? $botId;
	if (!$id || !get_transient('aielatex_'.$id)) { return $data; }
	if (isset($data['type']) && $data['type'] === 'live' && isset($data['data']) && !empty($data['data'])) {
		$data['data'] = str_replace("\\", "|", $data['data']);
	}
	return $data;
}, 10, 3);

function aielatex_shortcode_output($output, $tag, $attr) {
	if ('mwai_chatbot' === $tag || 'mwai_chatbot_v2' === $tag) {
		$botId = sanitize_text_field(isset($attr['custom_id']) && $attr['custom_id']) ? $attr['custom_id'] : (isset($attr['id']) ? $attr['id'] : 'default');
		if (isset($attr['latex']) && ($attr['latex'] == 'true' || $attr['latex'] == '1')) {
			set_transient('aielatex_'.$botId,true,24*60*60);
			wp_enqueue_style('katex');
			wp_enqueue_style('aielatex-public');
			wp_enqueue_script('katex');
			wp_enqueue_script('katex-auto-render');
			wp_enqueue_script('aielatex-public');
		} elseif (!isset($attr['latex']) || !($attr['latex'] == 'true' || $attr['latex'] == '1')) {
			delete_transient('aielatex_'.$botId);
		}
	}
	return $output;
}
add_filter('do_shortcode_tag', 'aielatex_shortcode_output', 10, 3);
